"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TableSchema_1 = require("../schema-builder/schema/TableSchema");
var ColumnSchema_1 = require("../schema-builder/schema/ColumnSchema");
var ForeignKeySchema_1 = require("../schema-builder/schema/ForeignKeySchema");
var IndexSchema_1 = require("../schema-builder/schema/IndexSchema");
var PrimaryKeySchema_1 = require("../schema-builder/schema/PrimaryKeySchema");
var STORAGE_SUFFIX = 'bas-sql';
var InfoStorage = (function () {
    function InfoStorage() {
    }
    InfoStorage.put = function (schema) {
        var tableSchemaData = {
            /**
           * Table name.
           */
            name: schema.name,
            /**
             * Table columns.
             */
            columns: !schema.columns ? [] : schema.columns.map(function (d) {
                return {
                    name: d.name,
                    /**
                     * Column type.
                     */
                    type: d.type,
                    /**
                     * Column's default value.
                     */
                    default: d.default,
                    /**
                     * Indicates if column is NULL, or is NOT NULL in the database.
                     */
                    isNullable: d.isNullable,
                    /**
                     * Indicates if column is auto-generated sequence.
                     */
                    isGenerated: d.isGenerated,
                    /**
                     * Indicates if column is a primary key.
                     */
                    isPrimary: d.isPrimary,
                    /**
                     * Indicates if column has unique value.
                     */
                    isUnique: d.isUnique,
                    /**
                     * Column's comment.
                     */
                    comment: d.comment
                };
            }),
            /**
             * Table indices.
             */
            indices: !schema.indices ? [] : schema.indices.map(function (d) {
                return {
                    tableName: d.tableName,
                    /**
                     * Index name.
                     */
                    name: d.name,
                    /**
                     * Columns included in this index.
                     */
                    columnNames: d.columnNames,
                    /**
                     * Indicates if this index is unique.
                     */
                    isUnique: d.isUnique
                };
            }),
            /**
             * Table foreign keys.
             */
            foreignKeys: schema.foreignKeys.map(function (d) {
                return {
                    name: d.name,
                    /**
                     * Column names which included by this foreign key.
                     */
                    columnNames: d.columnNames,
                    /**
                     * Table referenced in the foreign key.
                     */
                    referencedTableName: d.referencedTableName,
                    /**
                     * Column names which included by this foreign key.
                     */
                    referencedColumnNames: d.referencedColumnNames,
                    onDelete: d.onDelete
                };
            }),
            /**
             * Table primary keys.
             */
            primaryKeys: schema.primaryKeys.map(function (d) {
                return {
                    name: d.name,
                    /**
                     * Column to which this primary key is bind.
                     */
                    columnName: d.columnName,
                };
            })
        };
        localStorage.setItem(STORAGE_SUFFIX + ".table:" + schema.name, JSON.stringify(tableSchemaData));
        InfoStorage.addTable(schema.name);
    };
    InfoStorage.get = function (tableName) {
        var data = JSON.parse(localStorage.getItem(STORAGE_SUFFIX + ".table:" + tableName));
        var tableSchema = new TableSchema_1.TableSchema(tableName, [], false);
        var columns = data.columns.map(function (d) { return new ColumnSchema_1.ColumnSchema(d); });
        var foreignKeys = data.foreignKeys.map(function (d) { return new ForeignKeySchema_1.ForeignKeySchema(d.name, d.columnNames, d.referencedColumnNames, d.referencedTableName, d.onDelete); });
        var indices = data.indices.map(function (d) { return new IndexSchema_1.IndexSchema(d.tableName, d.name, d.columnNames, d.isUnique); });
        var primaryKeys = data.primaryKeys.map(function (d) { return new PrimaryKeySchema_1.PrimaryKeySchema(d.name, d.columnName); });
        tableSchema.addColumns(columns);
        tableSchema.addForeignKeys(foreignKeys);
        tableSchema.addPrimaryKeys(primaryKeys);
        tableSchema.indices = indices;
        return tableSchema;
    };
    InfoStorage.addTable = function (tableName) {
        var tableList = InfoStorage.getTablelist();
        if (tableList.indexOf(tableName) > -1) {
            return;
        }
        tableList.push(tableName);
        localStorage.setItem(STORAGE_SUFFIX + ".tableList", JSON.stringify(tableList));
    };
    InfoStorage.removeTable = function (tableName) {
        var tableList = InfoStorage.getTablelist();
        tableList = tableList.filter(function (name) { return name !== tableName; });
        localStorage.setItem(STORAGE_SUFFIX + ".tableList", JSON.stringify(tableList));
    };
    InfoStorage.getTablelist = function () {
        var tableList = localStorage.getItem(STORAGE_SUFFIX + ".tableList");
        return tableList ? JSON.parse(tableList) : [];
    };
    InfoStorage.clearTableList = function () {
        localStorage.removeItem(STORAGE_SUFFIX + ".tableList");
    };
    return InfoStorage;
}());
exports.InfoStorage = InfoStorage;

//# sourceMappingURL=info-storage.js.map
